==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/et_EE.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Seaded on uuendatud.",
"Activity" => "Toimingud",
"A file or folder has been <strong>shared</strong>" => "Fail või kataloog on <strong>jagatud</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Uus fail või kataloog on <strong>loodud</strong> jagatud kataloogi",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Fail või kataloog on <strong>muudetud</strong> jagatud kataloogis",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Fail või kataloog on <strong>kustutatud</strong> jagatud kataloogist",
"You created %1\$s" => "Sa tekitasid %1\$s",
"%2\$s created %1\$s" => "%2\$s tekitatud %1\$s",
"You changed %1\$s" => "Sa muutsid %1\$s",
"%2\$s changed %1\$s" => "%2\$s muutis %1\$s",
"You deleted %1\$s" => "Sa kustutasid %1\$s",
"%2\$s deleted %1\$s" => "%2\$s kustutas %1\$s",
"You shared %1\$s with %2\$s" => "Jagasid %1\$s  %2\$s kasutajaga",
"You shared %1\$s with group %2\$s" => "Jagasid %1\$s %2\$s grupiga",
"%2\$s shared %1\$s with you" => "%2\$s jagas sinuga %1\$s",
"Activity notification" => "Tegvuste teavitused",
"All Activities" => "Kõik tegevused",
"Activities by you" => "Sinu toimingud",
"Activities by others" => "Teiste toimingud",
"Shares" => "Jagamised",
"Files" => "Failid",
"%s and %s" => "%s ja %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s ja <strong class=\"tooltip\" title=\"%s\">%n veel</strong>","%s ja <strong class=\"tooltip\" title=\"%s\">%n veel</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s ja %n veel","%s ja %n veel"),
"Hello %s," => "Tere %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Sa sead selle teavituse, kuna viimase tunni jooksul toimusid %s sellised tegevused",
"You are receiving this email because in the last day the following things happened at %s" => "Sa sead selle teavituse, kuna viimase päeva jooksul toimusid %s sellised tegevused",
"You are receiving this email because in the last week the following things happened at %s" => "Sa sead selle teavituse, kuna viimase nädala jooksul toimusid %s sellised tegevused",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Siin näed sa sündmuste nimekirja kui sa hakkad %s kasutama.",
"No more events to load" => "Pole rohkem sündmusi, mida laadida.",
"Enable RSS feed" => "Luba RSS voog",
"Notifications" => "Teavitused",
"Mail" => "Kirjad",
"Stream" => "Voog",
"You need to set up your email address before you can receive notification emails." => "Enne teavituskirjade saamist pead sa lisama oma e-posti aadressi.",
"Send emails:" => "Saada kirjad:",
"Hourly" => "Iga tund",
"Daily" => "Iga päev",
"Weekly" => "Iga nädal",
"Activity feed" => "Toimingute voog",
"Personal activity feed for %s" => "Isiklik toimingute voog %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.3~~20141010%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/et_EE.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Seaded on uuendatud.",
"Activity" => "Toimingud",
"A file or folder has been <strong>shared</strong>" => "Fail või kataloog on <strong>jagatud</strong>",
"A new file or folder has been <strong>created</strong>" => "Uus fail või kataloog on <strong>loodud</strong>",
"A file or folder has been <strong>changed</strong>" => "Fail või kataloog on <strong>muudetud</strong>",
"A file or folder has been <strong>deleted</strong>" => "Fail või kataloog on <strong>kustutatud</strong>",
"You created %1\$s" => "Sa tekitasid %1\$s",
"%2\$s created %1\$s" => "%2\$s tekitatud %1\$s",
"%1\$s was created in a public folder" => "%1\$s lisati avalikku kausta",
"You changed %1\$s" => "Sa muutsid %1\$s",
"%2\$s changed %1\$s" => "%2\$s muutis %1\$s",
"You deleted %1\$s" => "Sa kustutasid %1\$s",
"%2\$s deleted %1\$s" => "%2\$s kustutas %1\$s",
"You shared %1\$s with %2\$s" => "Jagasid %1\$s  %2\$s kasutajaga",
"You shared %1\$s with group %2\$s" => "Jagasid %1\$s %2\$s grupiga",
"%2\$s shared %1\$s with you" => "%2\$s jagas sinuga %1\$s",
"You shared %1\$s via link" => "Jagasid %1\$s lingiga",
"Activity notification" => "Tegvuste teavitused",
"All Activities" => "Kõik tegevused",
"Activities by you" => "Sinu toimingud",
"Activities by others" => "Teiste toimingud",
"Shares" => "Jagamised",
"Files" => "Failid",
"in %s" => "kaustas %s",
"%s and %s" => "%s ja %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s ja <strong class=\"tooltip\" title=\"%s\">%n veel</strong>","%s ja <strong class=\"tooltip\" title=\"%s\">%n veel</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s ja %n veel","%s ja %n veel"),
"Hello %s," => "Tere %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Sa sead selle teavituse, kuna viimase tunni jooksul toimusid %s sellised tegevused",
"You are receiving this email because in the last day the following things happened at %s" => "Sa sead selle teavituse, kuna viimase päeva jooksul toimusid %s sellised tegevused",
"You are receiving this email because in the last week the following things happened at %s" => "Sa sead selle teavituse, kuna viimase nädala jooksul toimusid %s sellised tegevused",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Siin näed sa sündmuste nimekirja kui sa hakkad %s kasutama.",
"No more events to load" => "Pole rohkem sündmusi, mida laadida.",
"Enable RSS feed" => "Luba RSS voog",
"Notifications" => "Teavitused",
"Mail" => "Kirjad",
"Stream" => "Voog",
"Notify about my own actions" => "Teavita mind minu tegevustest",
"You need to set up your email address before you can receive notification emails." => "Enne teavituskirjade saamist pead sa lisama oma e-posti aadressi.",
"Send emails:" => "Saada kirjad:",
"Hourly" => "Iga tund",
"Daily" => "Iga päev",
"Weekly" => "Iga nädal",
"Activity feed" => "Toimingute voog",
"Personal activity feed for %s" => "Isiklik toimingute voog %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
